#
# spec file for package xf86-video-mach64
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xf86-video-mach64
Version:        6.10.0
Release:        1.3
Summary:        ATI Mach64 series video driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.xz
BuildRequires:  Mesa-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(libdrm) >= 2.2
BuildRequires:  pkgconfig(pciaccess) >= 0.12.901
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xf86driproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xorg-server) >= 1.2
BuildRequires:  pkgconfig(xproto)
Supplements:    modalias(xorg-x11-server:pci:v00001002d*sv*sd*bc03sc*i*)
# This was part of the xorg-x11-driver-video package up to version 7.6
Conflicts:      xorg-x11-driver-video <= 7.6
ExcludeArch:    s390 s390x
%{x11_abi_videodrv_req}

%description
mach64 is an Xorg driver for ATI Mach64 series video cards.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%files
%license COPYING
%doc ChangeLog README
%dir %{_libdir}/xorg/modules/drivers
%{_libdir}/xorg/modules/drivers/mach64_drv.so

%changelog
* Sun Oct 13 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 6.10.0
  * This release raises the minimum supported version of the Xorg
    server from 1.4 (released in 2007) to 1.18 (released in 2015).
    This includes the removal of the XAA code, which cannot be
    compiled for any Xserver newer than the 1.12 series, as it was
    removed in the Xorg 1.13 release.
* Mon Jul 11 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.9.7
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Build xz tarballs instead of bzip2
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * Fix compositing rotation
  * Fix debugging traces
  * Rename bool to boolean for OptionInfoRec.
  * configure: Include xorg-server.h before exa.h
- supersedes u_xorg-server-21.1.patch
* Fri Nov 12 2021 Stefan Dirsch <sndirsch@suse.com>
- u_xorg-server-21.1.patch
  * fixes build against xorg-server 21.1
* Wed Apr 21 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move license to licensedir)
- use https for urls
* Sat May 19 2018 sndirsch@suse.com
- Update to version 6.9.6
  * A boring release, fixing source compatibility with xserver 1.20.
* Tue May  5 2015 sndirsch@suse.com
- Update to version 6.9.5
  * preinit: Don't bother explicitly loading int10, vbe will do it for us
  * Bump minimum xserver to 1.4
  * Remove unused atidecoder.c & atidecoder.h
  * Remove unused atiaudio.c & ATIAudioNames declaration
  * Drop dependence on xf86PciInfo.h
  * mach64: fix build probably not required with pci access anyways
  * Deal with pPict->pDrawable == NULL for source-only pictures.
- deprecates
  * U_Deal-with-pPict-pDrawable-NULL-for-source-only-pictures.patch
  * U_mach64-fix-build-probably-not-required-with-pci-acce.patch
* Fri Feb  6 2015 sndirsch@suse.com
- U_mach64-fix-build-probably-not-required-with-pci-acce.patch
  * fixes build against xorg-server 1.17
* Mon Feb 24 2014 wbauer@tmo.at
- U_Deal-with-pPict-pDrawable-NULL-for-source-only-pictures.patch
  * Deal with pPict->pDrawable == NULL for source-only pictures.
    Falling back to software rendering for such source pictures
    (solid/gradient). (bnc#865607)
* Wed Aug  7 2013 ro@suse.de
- add ExcludeArch for s390 and s390x
* Wed Mar 20 2013 sndirsch@suse.com
- introduce hardware supplements conditional on xorg-x11-server
  package (bnc#810333)
* Sat Dec 22 2012 zaitor@opensuse.org
- Update to version 6.9.4:
  + Remove call to obsolete miInitializeBackingStore()
  + Remove dummy UTS / DFS hooks. fdo#51137
  + Mach64PixelARGB should use exaGetPixmapFirstPixel
  + Fix build with neither XAA nor EXA against xserver 1.13.0
  + Don't gratuitously disable Render when ShadowFBing
  + mach64: fix build on 32-bit. tvout code only builds on 32-bit.
- Drop U_mach64-fix-build-on-32-bit.patch, fixed upstream.
* Tue Sep 18 2012 sndirsch@suse.com
- U_mach64-fix-build-on-32-bit.patch
  * fix build on 32-bit. tvout code only builds on 32-bit.
* Mon Sep 17 2012 sndirsch@suse.com
- Update to version 6.9.3
  * fix build against server without XAA
* Thu Apr 19 2012 dimstar@opensuse.org
- Update to version 6.9.1:
  + Fall back to shadowfb if XAA is unavailable
- Use %%x11_abi_videodrv_req instead of static ABI Requires.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-video-mach64 from xorg-x11-driver-video.
  Initial version: 6.9.0.
